pub struct SponsorInfo {
pub sponsor_for_gas: RpcAddress,
pub sponsor_for_collateral: RpcAddress,
pub sponsor_gas_bound: U256,
pub sponsor_balance_for_gas: U256,
pub sponsor_balance_for_collateral: U256,
pub available_storage_points: U256,
pub used_storage_points: U256,
}Fields
sponsor_for_gas: RpcAddressThis is the address of the sponsor for gas cost of the contract.
sponsor_for_collateral: RpcAddressThis is the address of the sponsor for collateral of the contract.
sponsor_gas_bound: U256This is the upper bound of sponsor gas cost per tx.
sponsor_balance_for_gas: U256This is the amount of tokens sponsor for gas cost to the contract.
sponsor_balance_for_collateral: U256This is the amount of tokens sponsor for collateral to the contract.
available_storage_points: U256This is the amount of unused storage points (in terms of bytes).
used_storage_points: U256This is the amount of used storage points (in terms of bytes).
Implementations
Sourceimpl SponsorInfo
impl SponsorInfo
pub fn default(network: Network) -> Result<SponsorInfo, String>
pub fn try_from( sponsor_info: SponsorInfo, network: Network, ) -> Result<SponsorInfo, String>